pub struct ProcessProcManager<A> { /* private fields */ }Expand description
A ProcManager that manages each proc as a separate OS process (test-only toy).
This implementation launches a child via Command and relies on
kill_on_drop(true) so that children are SIGKILLed if the manager
(or host) drops. There is no proc control plane (no RPC to a
proc agent for shutdown) and no exit monitor wired here.
Consequently:
terminate()andkill()returnUnsupported.wait()is trivial (no lifecycle observation).
It follows a simple protocol:
Each process is launched with the following environment variables:
HYPERACTOR_HOST_BACKEND_ADDR: the backend address to which all messages are forwarded,HYPERACTOR_HOST_PROC_ID: the proc id to assign the launched proc, andHYPERACTOR_HOST_CALLBACK_ADDR: the channel address with which to return the proc’s address
The launched proc should also spawn an actor to manage it - the details of this are implementation dependent, and outside the scope of the process manager.
The function [boot_proc] provides a convenient implementation of the
protocol.
Implementations
Sourceimpl<A> ProcessProcManager<A>
impl<A> ProcessProcManager<A>